@@ -24,6 +24,9 @@ var (
 	b, _ = newTestBot()      // cached bot instance to avoid getMe method flooding
 	to   = &Chat{ID: chatID} // to chat recipient for send and edit methods
 	user = &User{ID: userID} // to user recipient for some special cases
+
+	logo  = FromURL("https://telegra.ph/file/c95b8fe46dd3df15d12e5.png")
+	thumb = FromURL("https://telegra.ph/file/fe28e378784b3a4e367fb.png")
 )
 
 func defaultSettings() Settings {
@@ -502,7 +505,7 @@ func TestBot(t *testing.T) {
 	assert.Equal(t, ErrBadRecipient, err)
 
 	photo := &Photo{
-		File:    FromURL("https://telegra.ph/file/65c5237b040ebf80ec278.jpg"),
+		File:    logo,
 		Caption: t.Name(),
 	}
 	var msg *Message
@@ -531,7 +534,7 @@ func TestBot(t *testing.T) {
 	})
 
 	t.Run("EditCaption()+ParseMode", func(t *testing.T) {
-		b.parseMode = ModeHTML
+		b.parseMode = "html"
 
 		edited, err := b.EditCaption(msg, "<b>new caption with html</b>")
 		require.NoError(t, err)
@@ -551,14 +554,15 @@ func TestBot(t *testing.T) {
 		require.NoError(t, err)
 		assert.Equal(t, "new caption with markdown (V2)", edited.Caption)
 		assert.Equal(t, EntityItalic, edited.CaptionEntities[0].Type)
-
-		b.parseMode = ModeDefault
 	})
 
 	t.Run("Edit(what=Media)", func(t *testing.T) {
+		photo.Caption = "<code>new caption with html</code>"
+
 		edited, err := b.Edit(msg, photo)
 		require.NoError(t, err)
 		assert.Equal(t, edited.Photo.UniqueID, photo.UniqueID)
+		assert.Equal(t, EntityCode, edited.CaptionEntities[0].Type)
 
 		resp, err := http.Get("https://telegra.ph/file/274e5eb26f348b10bd8ee.mp4")
 		require.NoError(t, err)
